#!/bin/bash

[ "$USER" != "root" ] && 
{
  echo "You need to run this script as ROOT. Exiting..."
  echo
  exit 1
}

OSDISK='/Volumes/Mac OS X Install Disc 1';

# Check for mounted volumes
[ -d "$OSDISK" ] || 
{
  echo "You need to mount Mac OS X Install Disc 1. Exiting..."
  exit 1
}

OSDMG='/Volumes/OSBoot';

# Check for mounted volumes
[ -d "$OSDMG" ] || 
{
  echo "You need to mount the 2.0.2 Firmware DMG. Exiting..."
  exit 1
}

echo "Mac OS X Install Disc 1:  Found"
echo "OSBoot:  Found"

# Make necessary directories
mkdir -p ./System/Library/Extensions;
mkdir -p ./usr/bin;
mkdir -p ./usr/sbin;

echo "Directories:  Created"

# Extract from OS Install disk, Essentials PKG
pax -r -p e -z -f /Volumes/Mac\ OS\ X\ Install\ Disc\ 1/System/Installation/Packages/Essentials.pkg/Contents/Archive.pax.gz \
'./System/Library/Extensions/IOUSBMassStorageClass.kext*' \
'./System/Library/Extensions/smbfs.kext*' \
'./System/Library/Extensions/udf.kext*' \
'./System/Library/Extensions/msdosfs.kext*' \
'./System/Library/Extensions/ntfs.kext*' \
'./System/Library/Extensions/IOStorageFamily.kext*' \
'./usr/bin/crontab' \
'./usr/sbin/cron' \
'./System/Library/Extensions/IOSCSIArchitectureModelFamily.kext*';

echo "Extract from OS Install disk, Essentials PKG:  Completed"

# Extract from OS Install disk, BSD PKG
pax -r -p e -z -f /Volumes/Mac\ OS\ X\ Install\ Disc\ 1/System/Installation/Packages/BSD.pkg/Contents/Archive.pax.gz \
'./usr/bin/nano';

echo "Extract from OS Install disk, BSD PKG:  Completed"

# mach_kernel.prelink
cp -p /Volumes/OSBoot//mach_kernel.prelink .

echo "Copy mach_kernel.prelink:  Completed"

# Make sure mach_kernel.prelink input file is here

if [ ! -f mach_kernel.prelink ]
then
	echo =================================================
	echo ==== Error!
	echo ==== You must first copy "mach_kernel.prelink"
	echo ==== into current directory!!
	echo =================================================

	exit 1
fi

# ==== decompress original mach_kernel.prelink file

echo ========= decompress kernel =========
./prelink_tool -d mach_kernel.prelink mach_kernel_patched.bin
if [ $? -ne 0 ]; then exit 1; fi

# ==== patch the decompressed kernel
echo ======== patch kernel =========
./poke mach_kernel_patched.bin 0x51f55e 0x75:0x75 0x34:0x30
if [ $? -ne 0 ]; then exit 1; fi

./poke mach_kernel_patched.bin 0x52023e 0x75:0x75 0x34:0x30
if [ $? -ne 0 ]; then exit 1; fi

./poke mach_kernel_patched.bin 0x51f576 0x75:0x75 0x1c:0x18
if [ $? -ne 0 ]; then exit 1; fi

./poke mach_kernel_patched.bin 0x520256 0x75:0x75 0x1c:0x18
if [ $? -ne 0 ]; then exit 1; fi

# ==== compress the patched kernel
echo ======= compress kernel =======
./prelink_tool -e mach_kernel_patched.bin mach_kernel_patched.prelink
if [ $? -ne 0 ]; then exit 1; fi

# Change permissions
chown -R root:wheel ./System;
chown -R root:wheel ./mach_kernel.prelink;
chown -R root:wheel ./usr
chmod -R 755 ./System;
chmod -R 755 ./mach_kernel.prelink;
chmod -R 755 ./usr;

echo "Set Permissions:  Completed"

tar cvf ../Take2USB.tar ../Take2USB